## MEFrpLib

<p align="right">based on MEFrp API<br>presented by LxHTT</p>

这是一个封装了MirrorEdgeFrp API的Python库。

### 安装

___

```command
pip install MEFrpLib
```

### 开始使用  

___

#### 导入  

```python
import MEFrpLib
```
